@@ -20,7 +20,7 @@ use tg_utils::{
 use crate::error::ContractError;
 use crate::msg::{
     ClaimsResponse, ExecuteMsg, InstantiateMsg, PreauthResponse, QueryMsg, StakedResponse,
-    TotalWeightResponse, UnbondingPeriodResponse,
+    TotalPointsResponse, UnbondingPeriodResponse,
 };
 use crate::state::{claims, Config, CONFIG, STAKE};
 
@@ -56,7 +56,7 @@ pub fn instantiate(
 
     let config = Config {
         denom: msg.denom,
-        tokens_per_weight: msg.tokens_per_weight,
+        tokens_per_point: msg.tokens_per_point,
         min_bond,
         unbonding_period: Duration::new(msg.unbonding_period),
         auto_return_limit: msg.auto_return_limit,
@@ -317,15 +317,15 @@ fn update_membership(
     cfg: &Config,
     height: u64,
 ) -> StdResult<Vec<SubMsg>> {
-    // update their membership weight
-    let new = calc_weight(new_stake, cfg);
+    // update their membership points
+    let new = calc_points(new_stake, cfg);
     let old = members().may_load(storage, &sender)?;
 
     // short-circuit if no change
     if new == old {
         return Ok(vec![]);
     }
-    // otherwise, record change of weight
+    // otherwise, record change of points
     match new.as_ref() {
         Some(w) => members().save(storage, &sender, w, height),
         None => members().remove(storage, &sender, height),
@@ -345,11 +345,11 @@ fn update_membership(
     })
 }
 
-fn calc_weight(stake: Uint128, cfg: &Config) -> Option<u64> {
+fn calc_points(stake: Uint128, cfg: &Config) -> Option<u64> {
     if stake < cfg.min_bond {
         None
     } else {
-        let w = stake.u128() / (cfg.tokens_per_weight.u128());
+        let w = stake.u128() / (cfg.tokens_per_point.u128());
         Some(w as u64)
     }
 }
@@ -449,10 +449,10 @@ pub fn query(deps: Deps, _env: Env, msg: QueryMsg) -> StdResult<Binary> {
             at_height: height,
         } => to_binary(&query_member(deps, addr, height)?),
         ListMembers { start_after, limit } => to_binary(&list_members(deps, start_after, limit)?),
-        ListMembersByWeight { start_after, limit } => {
-            to_binary(&list_members_by_weight(deps, start_after, limit)?)
+        ListMembersByPoints { start_after, limit } => {
+            to_binary(&list_members_by_points(deps, start_after, limit)?)
         }
-        TotalWeight {} => to_binary(&query_total_weight(deps)?),
+        TotalPoints {} => to_binary(&query_total_points(deps)?),
         Claims {
             address,
             limit,
@@ -489,10 +489,10 @@ pub fn query(deps: Deps, _env: Env, msg: QueryMsg) -> StdResult<Binary> {
     }
 }
 
-fn query_total_weight(deps: Deps) -> StdResult<TotalWeightResponse> {
-    let weight = TOTAL.load(deps.storage)?;
+fn query_total_points(deps: Deps) -> StdResult<TotalPointsResponse> {
+    let points = TOTAL.load(deps.storage)?;
     let denom = CONFIG.load(deps.storage)?.denom;
-    Ok(TotalWeightResponse { weight, denom })
+    Ok(TotalPointsResponse { points, denom })
 }
 
 pub fn query_staked(deps: Deps, addr: String) -> StdResult<StakedResponse> {
@@ -507,16 +507,16 @@ pub fn query_staked(deps: Deps, addr: String) -> StdResult<StakedResponse> {
 
 fn query_member(deps: Deps, addr: String, height: Option<u64>) -> StdResult<MemberResponse> {
     let addr = deps.api.addr_validate(&addr)?;
-    let weight = match height {
+    let points = match height {
         Some(h) => members().may_load_at_height(deps.storage, &addr, h),
         None => members().may_load(deps.storage, &addr),
     }?;
-    Ok(MemberResponse { weight })
+    Ok(MemberResponse { points })
 }
 
 // settings for pagination
-const MAX_LIMIT: u32 = 30;
-const DEFAULT_LIMIT: u32 = 10;
+const MAX_LIMIT: u32 = 100;
+const DEFAULT_LIMIT: u32 = 30;
 
 fn list_members(
     deps: Deps,
@@ -531,10 +531,10 @@ fn list_members(
         .range(deps.storage, start, None, Order::Ascending)
         .take(limit)
         .map(|item| {
-            let (addr, weight) = item?;
+            let (addr, points) = item?;
             Ok(Member {
                 addr: addr.into(),
-                weight,
+                points,
             })
         })
         .collect();
@@ -542,24 +542,24 @@ fn list_members(
     Ok(MemberListResponse { members: members? })
 }
 
-fn list_members_by_weight(
+fn list_members_by_points(
     deps: Deps,
     start_after: Option<Member>,
     limit: Option<u32>,
 ) -> StdResult<MemberListResponse> {
     let limit = limit.unwrap_or(DEFAULT_LIMIT).min(MAX_LIMIT) as usize;
-    let start = start_after.map(|m| Bound::exclusive((m.weight, m.addr.as_str()).joined_key()));
+    let start = start_after.map(|m| Bound::exclusive((m.points, m.addr.as_str()).joined_key()));
 
     let members: StdResult<Vec<_>> = members()
         .idx
-        .weight
+        .points
         .range(deps.storage, None, start, Order::Descending)
         .take(limit)
         .map(|item| {
-            let (addr, weight) = item?;
+            let (addr, points) = item?;
             Ok(Member {
                 addr: addr.into(),
-                weight,
+                points,
             })
         })
         .collect();
@@ -592,24 +592,24 @@ mod tests {
     const USER2: &str = "user2";
     const USER3: &str = "user3";
     const DENOM: &str = "stake";
-    const TOKENS_PER_WEIGHT: Uint128 = Uint128::new(1_000);
+    const TOKENS_PER_POINT: Uint128 = Uint128::new(1_000);
     const MIN_BOND: Uint128 = Uint128::new(5_000);
     const UNBONDING_DURATION: u64 = 100;
 
     fn default_instantiate(deps: DepsMut) {
-        do_instantiate(deps, TOKENS_PER_WEIGHT, MIN_BOND, UNBONDING_DURATION, 0)
+        do_instantiate(deps, TOKENS_PER_POINT, MIN_BOND, UNBONDING_DURATION, 0)
     }
 
     fn do_instantiate(
         deps: DepsMut,
-        tokens_per_weight: Uint128,
+        tokens_per_point: Uint128,
         min_bond: Uint128,
         unbonding_period: u64,
         auto_return_limit: u64,
     ) {
         let msg = InstantiateMsg {
             denom: "stake".to_owned(),
-            tokens_per_weight,
+            tokens_per_point,
             min_bond,
             unbonding_period,
             admin: Some(INIT_ADMIN.into()),
@@ -666,8 +666,8 @@ mod tests {
         let res = ADMIN.query_admin(deps.as_ref()).unwrap();
         assert_eq!(Some(INIT_ADMIN.into()), res.admin);
 
-        let res = query_total_weight(deps.as_ref()).unwrap();
-        assert_eq!(0, res.weight);
+        let res = query_total_points(deps.as_ref()).unwrap();
+        assert_eq!(0, res.points);
         assert_eq!("stake".to_owned(), res.denom);
 
         let raw = query(deps.as_ref(), mock_env(), QueryMsg::Configuration {}).unwrap();
@@ -676,7 +676,7 @@ mod tests {
             res,
             Config {
                 denom: "stake".to_owned(),
-                tokens_per_weight: TOKENS_PER_WEIGHT,
+                tokens_per_point: TOKENS_PER_POINT,
                 min_bond: MIN_BOND,
                 unbonding_period: Duration::new(UNBONDING_DURATION),
                 auto_return_limit: 0,
@@ -697,32 +697,32 @@ mod tests {
     fn get_member(deps: Deps, addr: String, at_height: Option<u64>) -> Option<u64> {
         let raw = query(deps, mock_env(), QueryMsg::Member { addr, at_height }).unwrap();
         let res: MemberResponse = from_slice(&raw).unwrap();
-        res.weight
+        res.points
     }
 
     // this tests the member queries
     fn assert_users(
         deps: Deps,
-        user1_weight: Option<u64>,
-        user2_weight: Option<u64>,
-        user3_weight: Option<u64>,
+        user1_points: Option<u64>,
+        user2_points: Option<u64>,
+        user3_points: Option<u64>,
         height: Option<u64>,
     ) {
         let member1 = get_member(deps, USER1.into(), height);
-        assert_eq!(member1, user1_weight);
+        assert_eq!(member1, user1_points);
 
         let member2 = get_member(deps, USER2.into(), height);
-        assert_eq!(member2, user2_weight);
+        assert_eq!(member2, user2_points);
 
         let member3 = get_member(deps, USER3.into(), height);
-        assert_eq!(member3, user3_weight);
+        assert_eq!(member3, user3_points);
 
         // this is only valid if we are not doing a historical query
         if height.is_none() {
             // compute expected metrics
-            let weights = vec![user1_weight, user2_weight, user3_weight];
-            let sum: u64 = weights.iter().map(|x| x.unwrap_or_default()).sum();
-            let count = weights.iter().filter(|x| x.is_some()).count();
+            let points = vec![user1_points, user2_points, user3_points];
+            let sum: u64 = points.iter().map(|x| x.unwrap_or_default()).sum();
+            let count = points.iter().filter(|x| x.is_some()).count();
 
             // TODO: more detailed compare?
             let msg = QueryMsg::ListMembers {
@@ -733,9 +733,9 @@ mod tests {
             let members: MemberListResponse = from_slice(&raw).unwrap();
             assert_eq!(count, members.members.len());
 
-            let raw = query(deps, mock_env(), QueryMsg::TotalWeight {}).unwrap();
-            let total: TotalWeightResponse = from_slice(&raw).unwrap();
-            assert_eq!(sum, total.weight); // 17 - 11 + 15 = 21
+            let raw = query(deps, mock_env(), QueryMsg::TotalPoints {}).unwrap();
+            let total: TotalPointsResponse = from_slice(&raw).unwrap();
+            assert_eq!(sum, total.points); // 17 - 11 + 15 = 21
         }
     }
 
@@ -757,20 +757,20 @@ mod tests {
         default_instantiate(deps.as_mut());
         let height = mock_env().block.height;
 
-        // Assert original weights
+        // Assert original points
         assert_users(deps.as_ref(), None, None, None, None);
 
         // ensure it rounds down, and respects cut-off
         bond(deps.as_mut(), 12_000, 7_500, 4_000, 1);
 
-        // Assert updated weights
+        // Assert updated points
         assert_stake(deps.as_ref(), 12_000, 7_500, 4_000);
         assert_users(deps.as_ref(), Some(12), Some(7), None, None);
 
         // add some more, ensure the sum is properly respected (7.5 + 7.6 = 15 not 14)
         bond(deps.as_mut(), 0, 7_600, 1_200, 2);
 
-        // Assert updated weights
+        // Assert updated points
         assert_stake(deps.as_ref(), 12_000, 15_100, 5_200);
         assert_users(deps.as_ref(), Some(12), Some(15), Some(5), None);
 
@@ -789,13 +789,13 @@ mod tests {
         bond(deps.as_mut(), 12_000, 7_500, 4_000, 1);
 
         let member1 = query_member(deps.as_ref(), USER1.into(), None).unwrap();
-        assert_eq!(member1.weight, Some(12));
+        assert_eq!(member1.points, Some(12));
 
         let member2 = query_member(deps.as_ref(), USER2.into(), None).unwrap();
-        assert_eq!(member2.weight, Some(7));
+        assert_eq!(member2.points, Some(7));
 
         let member3 = query_member(deps.as_ref(), USER3.into(), None).unwrap();
-        assert_eq!(member3.weight, None);
+        assert_eq!(member3.points, None);
 
         let members = list_members(deps.as_ref(), None, None).unwrap().members;
         assert_eq!(members.len(), 2);
@@ -805,11 +805,11 @@ mod tests {
             vec![
                 Member {
                     addr: USER1.into(),
-                    weight: 12
+                    points: 12
                 },
                 Member {
                     addr: USER2.into(),
-                    weight: 7
+                    points: 7
                 },
             ]
         );
@@ -822,7 +822,7 @@ mod tests {
             members,
             vec![Member {
                 addr: USER1.into(),
-                weight: 12
+                points: 12
             },]
         );
 
@@ -837,7 +837,7 @@ mod tests {
             members,
             vec![Member {
                 addr: USER2.into(),
-                weight: 7
+                points: 7
             },]
         );
 
@@ -850,37 +850,37 @@ mod tests {
     }
 
     #[test]
-    fn try_list_members_by_weight() {
+    fn try_list_members_by_points() {
         let mut deps = mock_dependencies();
         default_instantiate(deps.as_mut());
 
         bond(deps.as_mut(), 11_000, 6_500, 5_000, 1);
 
-        let members = list_members_by_weight(deps.as_ref(), None, None)
+        let members = list_members_by_points(deps.as_ref(), None, None)
             .unwrap()
             .members;
         assert_eq!(members.len(), 3);
-        // Assert the set is sorted by (descending) weight
+        // Assert the set is sorted by (descending) points
         assert_eq!(
             members,
             vec![
                 Member {
                     addr: USER1.into(),
-                    weight: 11
+                    points: 11
                 },
                 Member {
                     addr: USER2.into(),
-                    weight: 6
+                    points: 6
                 },
                 Member {
                     addr: USER3.into(),
-                    weight: 5
+                    points: 5
                 }
             ]
         );
 
         // Test pagination / limits
-        let members = list_members_by_weight(deps.as_ref(), None, Some(1))
+        let members = list_members_by_points(deps.as_ref(), None, Some(1))
             .unwrap()
             .members;
         assert_eq!(members.len(), 1);
@@ -889,14 +889,14 @@ mod tests {
             members,
             vec![Member {
                 addr: USER1.into(),
-                weight: 11
+                points: 11
             },]
         );
 
         // Next page
         let last = members.last().unwrap();
         let start_after = Some(last.clone());
-        let members = list_members_by_weight(deps.as_ref(), start_after, None)
+        let members = list_members_by_points(deps.as_ref(), start_after, None)
             .unwrap()
             .members;
         assert_eq!(members.len(), 2);
@@ -906,11 +906,11 @@ mod tests {
             vec![
                 Member {
                     addr: USER2.into(),
-                    weight: 6
+                    points: 6
                 },
                 Member {
                     addr: USER3.into(),
-                    weight: 5
+                    points: 5
                 }
             ]
         );
@@ -918,7 +918,7 @@ mod tests {
         // Assert there's no more
         let last = members.last().unwrap();
         let start_after = Some(last.clone());
-        let members = list_members_by_weight(deps.as_ref(), start_after, Some(1))
+        let members = list_members_by_points(deps.as_ref(), start_after, Some(1))
             .unwrap()
             .members;
         assert_eq!(members.len(), 0);
@@ -934,14 +934,14 @@ mod tests {
         bond(deps.as_mut(), 12_000, 7_500, 4_000, 1);
         unbond(deps.as_mut(), 4_500, 2_600, 1_111, 2, 0);
 
-        // Assert updated weights
+        // Assert updated points
         assert_stake(deps.as_ref(), 7_500, 4_900, 2_889);
         assert_users(deps.as_ref(), Some(7), None, None, None);
 
-        // Adding a little more returns weight
+        // Adding a little more returns points
         bond(deps.as_mut(), 600, 100, 2_222, 3);
 
-        // Assert updated weights
+        // Assert updated points
         assert_users(deps.as_ref(), Some(8), Some(5), Some(5), None);
 
         // check historical queries all work
@@ -1661,11 +1661,11 @@ mod tests {
 
     #[test]
     fn ensure_bonding_edge_cases() {
-        // use min_bond 0, tokens_per_weight 500
+        // use min_bond 0, tokens_per_points 500
         let mut deps = mock_dependencies();
         do_instantiate(deps.as_mut(), Uint128::new(100), Uint128::zero(), 5, 0);
 
-        // setting 50 tokens, gives us Some(0) weight
+        // setting 50 tokens, gives us Some(0) points
         // even setting to 1 token
         bond(deps.as_mut(), 50, 1, 102, 1);
         assert_users(deps.as_ref(), Some(0), Some(0), Some(1), None);
@@ -1730,7 +1730,7 @@ mod tests {
         use super::*;
 
         fn do_instantiate(deps: DepsMut, limit: u64) {
-            super::do_instantiate(deps, TOKENS_PER_WEIGHT, MIN_BOND, UNBONDING_DURATION, limit)
+            super::do_instantiate(deps, TOKENS_PER_POINT, MIN_BOND, UNBONDING_DURATION, limit)
         }
 
         /// Helper for asserting if expected transfers occurred in response. Panics if any non
